@@ -1,9 +1,18 @@
 import os
-import re
-import colorama
-from colorama import Fore, Style
+import sys
+from rich.console import Console
 
-colorama.init()
+
+if sys.platform.startswith('win'):
+    is_win = True
+    dir_char = '\\'
+else:
+    is_win = False
+    dir_char = '/'
+QproDefaultConsole = Console()
+QproErrorString = '[bold red][ERRO]'
+QproInfoString = '[bold cyan][INFO]'
+QproWarnString = '[bold yellow][WARN]'
 name = 'QuickProject'
 
 
@@ -27,33 +36,34 @@ class SshProtocol:
     def get_file_or_folder(user, domain, target, port, path):
         return os.system('scp -P %s -r %s %s' % (port, user + '@\\[' + domain + '\\]:' + target + path, path))
 
+    @staticmethod
+    def ls(user, domain, target, port, path):
+        return os.system(f"ssh -P {port} {user + '@' + domain} 'ls {target + path}'")
+
     @staticmethod
     def ssh(user, domain, target, port):
-        return os.system("ssh -p %s -t %s 'cd %s ; exec $SHELL -l'" % (port, user + '@' + domain, target))
+        return os.system(f"ssh -P {port} -t {user + '@' + domain} 'cd {target} ; exec $SHELL -l'")
 
 
-def basic_string_replace(ss):
-    ss = ss.split('\n')
-    ret = ''
-    for i in ss:
-        if '[' in i:
-            replace_list = re.findall('\[(.*?)]', i)
-            split_list = re.split('\[.*?]', i)
-            for p in range(len(split_list)):
-                ret += Fore.CYAN + split_list[p] + Style.RESET_ALL
-                if p < len(replace_list):
-                    ret += Fore.RED + '[' + Fore.YELLOW + replace_list[p] + Fore.RED + ']' + Style.RESET_ALL
-        else:
-            ret += i
-        ret += '\n'
-    return ret
+def menu_output(menu):
+    from rich.table import Table, Column
+    from rich.box import SIMPLE
+
+    tb = Table(*[Column('Parameter', justify='full', style='bold yellow'),
+                 Column('Description', justify='right', style='bold cyan')],
+               show_edge=False, show_header=False, row_styles=['none', 'dim'], box=SIMPLE, pad_edge=False,
+               title=f'[bold underline] {menu["title"]}[dim]Author: RhythmLian\n')
+    for line in menu['lines']:
+        tb.add_row((menu['prefix'] + ' ' if line[0].startswith('-') else '') + line[0], line[1])
+    QproDefaultConsole.print(tb, justify='center')
+    QproDefaultConsole.print('\nDOC: https://rhythmlian.cn/2020/02/14/QuickProject/', justify='center')
 
 
 def get_config(exit_if_failed: bool = True):
     config = {}
     try:
         with open('project_configure.csv', 'r') as f:
-            for row in f.readlines():
+            for row in f.read().strip().split('\n'):
                 row = row.replace('\,', '--QPRO-IS-SPLIT--')
                 row = [i.replace('--QPRO-IS-SPLIT--', ',') for i in row.split(',')]
                 config[row[0]] = [i.strip() for i in row[1:]]
@@ -63,7 +73,9 @@ def get_config(exit_if_failed: bool = True):
                 config[i] = config[i][0]
     except IOError:
         if exit_if_failed:
-            exit("No file named: project_configure.csv\n May you need run:\"Qpro -init\" first!")
+            QproDefaultConsole.print(
+                QproErrorString, "No file named: project_configure.csv\n May you need run:\"Qpro -init\" first!")
+            exit(0)
         else:
             return False
     return config
