@@ -7,11 +7,6 @@ import tkinter as tk
 from tkinter import filedialog, messagebox
 from QuickProject import get_config
 
-if sys.platform.startswith('win'):
-    dir_char = '\\'
-else:
-    dir_char = '/'
-
 
 def read_file(filename):
     try:
@@ -111,7 +106,8 @@ ll = tk.Label(win, textvariable=path3, width=width, fg='red')
 
 def main():
     if not get_config(False) and sys.argv[1] != '-ff':
-        exit("You must run \"Qpro -init\" first")
+        from QuickProject import QproDefaultConsole, QproErrorString
+        return QproDefaultConsole.print(QproErrorString, "You must run \"Qpro -init\" first")
     tk.Label(win, text='%12s' % "文件1路径:").grid(row=0, column=0)
     tk.Label(win, textvariable=path1, width=width).grid(row=0, column=1)
     tk.Button(win, text="路径选择", command=get_path1).grid(row=0, column=2)
